use strict;
use warnings;
package Alien::libpid;

# ABSTRACT: Perl distribution for libpid
# VERSION

use parent 'Alien::Base';

our $VERSION = '0.02';

=pod

=encoding utf8

=head1 NAME

Alien::libpid - Perl distribution for libpid

=head1 INSTALL

    cpan Alien::libpid

=cut

1;
__END__


=head1 GIT REPOSITORY

L<http://github.com/athreef/Alien-libpid>

=head1 SEE ALSO

L<Alien>
L<libpid|http://github.com/a3f/libpid>

=head1 AUTHOR

Ahmad Fatoum C<< <athreef@cpan.org> >>, L<http://a3f.at>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2016 Ahmad Fatoum

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
